@@ -206,7 +206,7 @@ CREATE FUNCTION pgroonga.options(internal)
 DELETE FROM pg_catalog.pg_am WHERE amname = 'pgroonga';
 INSERT INTO pg_catalog.pg_am VALUES(
 	'pgroonga',	-- amname
-	11,		-- amstrategies
+	15,		-- amstrategies
 	0,		-- amsupport
 	true,		-- amcanorder
 	true,		-- amcanorderbyop
@@ -372,3 +372,66 @@ CREATE OPERATOR CLASS pgroonga.text_regexp_ops FOR TYPE text
 CREATE OPERATOR CLASS pgroonga.varchar_regexp_ops FOR TYPE varchar
 	USING pgroonga AS
 		OPERATOR 10 @~;
+
+
+/* v2 */
+CREATE FUNCTION pgroonga.match_text(text, text)
+	RETURNS bool
+	AS 'MODULE_PATHNAME', 'pgroonga_match_text'
+	LANGUAGE C
+	IMMUTABLE
+	STRICT;
+
+CREATE OPERATOR &@ (
+	PROCEDURE = pgroonga.match_text,
+	LEFTARG = text,
+	RIGHTARG = text
+);
+
+CREATE FUNCTION pgroonga.query_text(text, text)
+	RETURNS bool
+	AS 'MODULE_PATHNAME', 'pgroonga_query_text'
+	LANGUAGE C
+	IMMUTABLE
+	STRICT;
+
+CREATE OPERATOR &? (
+	PROCEDURE = pgroonga.query_text,
+	LEFTARG = text,
+	RIGHTARG = text
+);
+
+CREATE FUNCTION pgroonga.match_contain_text(text, text[])
+	RETURNS bool
+	AS 'MODULE_PATHNAME', 'pgroonga_match_contain_text'
+	LANGUAGE C
+	IMMUTABLE
+	STRICT;
+
+CREATE OPERATOR &@> (
+	PROCEDURE = pgroonga.match_contain_text,
+	LEFTARG = text,
+	RIGHTARG = text[]
+);
+
+CREATE FUNCTION pgroonga.query_contain_text(text, text[])
+	RETURNS bool
+	AS 'MODULE_PATHNAME', 'pgroonga_query_contain_text'
+	LANGUAGE C
+	IMMUTABLE
+	STRICT;
+
+CREATE OPERATOR &?> (
+	PROCEDURE = pgroonga.query_contain_text,
+	LEFTARG = text,
+	RIGHTARG = text[]
+);
+
+CREATE OPERATOR CLASS pgroonga.text_full_text_search_ops_v2 FOR TYPE text
+	USING pgroonga AS
+		OPERATOR 6 pg_catalog.~~,
+		OPERATOR 7 pg_catalog.~~*,
+		OPERATOR 12 &@,
+		OPERATOR 13 &?,
+		OPERATOR 14 &@> (text, text[]),
+		OPERATOR 15 &?> (text, text[]);
